@@ -104,20 +104,20 @@ exchange_search_body_contains (struct _ESExp *f,
 	}
 
 	/* if we need to setup a hash of summary items, this way we get
-	   access to the summary memory which is locked for the duration of
-	   the search, and wont vanish on us */
+	 * access to the summary memory which is locked for the duration of
+	 * the search, and wont vanish on us */
 	if (uid_hash == NULL) {
 		gint i;
 
 		uid_hash = g_hash_table_new (g_str_hash, g_str_equal);
 		for (i = 0; i < s->summary->len; i++) {
-			info = camel_folder_summary_uid (s->folder->summary, s->summary->pdata[i]);
+			info = camel_folder_summary_get (s->folder->summary, s->summary->pdata[i]);
 			g_hash_table_insert (uid_hash, s->summary->pdata[i], info);
 		}
 	}
 
 	for (i = 0; i < found_uids->len; i++) {
-		if (g_hash_table_lookup_extended (uid_hash, found_uids->pdata[i], (gpointer)&real_uid, (gpointer)&info))
+		if (g_hash_table_lookup_extended (uid_hash, found_uids->pdata[i], (gpointer) &real_uid, (gpointer) &info))
 			g_ptr_array_add (r->value.ptrarray, real_uid);
 		g_free (found_uids->pdata[i]);
 	}
